@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2014 by Dominique Dumont.
+# This software is Copyright (c) 2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::ListEditor;
-$Config::Model::Tk::ListEditor::VERSION = '1.344';
+$Config::Model::Tk::ListEditor::VERSION = '1.351';
 use strict;
 use warnings;
 use Carp;
@@ -69,7 +69,7 @@ sub Populate {
 
     my $elt_button_frame = $cw->Frame(qw/-relief raised -borderwidth 2/)->pack(@fbe1);
     my $frame_title      = $list->element_name;
-    $frame_title .= ( defined $value_type and $value_type =~ /node/ ) ? 'elements' : 'values';
+    $frame_title .= ( defined $value_type and $value_type =~ /node/ ) ? ' elements' : ' list';
     $elt_button_frame->Label( -text => $frame_title )->pack();
 
     my $tklist = $elt_button_frame->Scrolled(
@@ -79,8 +79,10 @@ sub Populate {
         -height     => 8,
     )->pack(@fbe1);
 
-    $balloon->attach( $tklist,
-        -msg => 'select an element and perform ' . 'an action on the right' );
+    $balloon->attach(
+        $tklist,
+        -msg => 'select an element and perform an action with one of the buttons below'
+    );
 
     my $right_frame = $elt_button_frame->Frame->pack( @fxe1, qw/-side right -anchor n/ );
 
